@@ -19,6 +19,8 @@ import (
 	"github.com/sirupsen/logrus"
 )
 
+var HideProgress bool
+
 type Status = string
 
 const (
@@ -243,13 +245,15 @@ func canonicalLocalPath(s string) (string, error) {
 }
 
 func copyLocal(dst, src string, expectedDigest digest.Digest) error {
-	if err := validateLocalFileDigest(src, expectedDigest); err != nil {
-		return err
-	}
 	srcPath, err := canonicalLocalPath(src)
 	if err != nil {
 		return err
 	}
+
+	if err := validateLocalFileDigest(srcPath, expectedDigest); err != nil {
+		return err
+	}
+
 	if dst == "" {
 		// empty dst means caching-only mode
 		return nil
@@ -295,6 +299,9 @@ func createBar(size int64) (*pb.ProgressBar, error) {
 	if isatty.IsTerminal(os.Stdout.Fd()) || isatty.IsCygwinTerminal(os.Stdout.Fd()) {
 		bar.SetTemplateString(`{{counters . }} {{bar . | green }} {{percent .}} {{speed . "%s/s"}}`)
 		bar.SetRefreshRate(200 * time.Millisecond)
+	} else if HideProgress {
+		bar.Set(pb.ReturnSymbol, "")
+		bar.SetTemplateString("")
 	} else {
 		bar.Set(pb.Terminal, false)
 		bar.Set(pb.ReturnSymbol, "\n")
