@@ -1,7 +1,10 @@
 package downloader
 
 import (
+	"io/ioutil"
+	"os"
 	"path/filepath"
+	"runtime"
 	"testing"
 
 	"github.com/opencontainers/go-digest"
@@ -14,6 +17,11 @@ const (
 	dummyRemoteFileDigest = "sha256:58d2de96f9d91f0acd93cb1e28bf7c42fc86079037768d6aa63b4e7e7b3c9be0"
 )
 
+func TestMain(m *testing.M) {
+	HideProgress = true
+	os.Exit(m.Run())
+}
+
 func TestDownloadRemote(t *testing.T) {
 	if testing.Short() {
 		t.Skip()
@@ -80,3 +88,45 @@ func TestDownloadRemote(t *testing.T) {
 		assert.Equal(t, StatusUsedCache, r.Status)
 	})
 }
+
+func TestDownloadLocal(t *testing.T) {
+
+	if runtime.GOOS == "windows" {
+		// FIXME: `TempDir RemoveAll cleanup: remove C:\users\runner\Temp\TestDownloadLocalwithout_digest2738386858\002\test-file: Sharing violation.`
+		t.Skip("Skipping on windows")
+	}
+
+	const emptyFileDigest = "sha256:e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855"
+	const testDownloadLocalDigest = "sha256:0c1e0fba69e8919b306d030bf491e3e0c46cf0a8140ff5d7516ba3a83cbea5b3"
+
+	t.Run("without digest", func(t *testing.T) {
+		localPath := filepath.Join(t.TempDir(), t.Name())
+		localFile := filepath.Join(t.TempDir(), "test-file")
+		os.Create(localFile)
+		testLocalFileURL := "file://" + localFile
+
+		r, err := Download(localPath, testLocalFileURL)
+		assert.NilError(t, err)
+		assert.Equal(t, StatusDownloaded, r.Status)
+	})
+
+	t.Run("with file digest", func(t *testing.T) {
+		localPath := filepath.Join(t.TempDir(), t.Name())
+		localTestFile := filepath.Join(t.TempDir(), "some-file")
+		testDownloadFileContents := []byte("TestDownloadLocal")
+
+		ioutil.WriteFile(localTestFile, testDownloadFileContents, 0644)
+		testLocalFileURL := "file://" + localTestFile
+		wrongDigest := digest.Digest(emptyFileDigest)
+
+		_, err := Download(localPath, testLocalFileURL, WithExpectedDigest(wrongDigest))
+		assert.ErrorContains(t, err, "expected digest")
+
+		r, err := Download(localPath, testLocalFileURL, WithExpectedDigest(testDownloadLocalDigest))
+		assert.NilError(t, err)
+		assert.Equal(t, StatusDownloaded, r.Status)
+
+		os.Remove(localTestFile)
+	})
+
+}
