@@ -1,6 +1,7 @@
 package hostagent
 
 import (
+	"bytes"
 	"context"
 	"encoding/json"
 	"errors"
@@ -31,6 +32,7 @@ import (
 	"github.com/lima-vm/lima/pkg/store"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/lima-vm/sshocker/pkg/ssh"
+	"github.com/sethvargo/go-password/password"
 	"github.com/sirupsen/logrus"
 )
 
@@ -111,6 +113,9 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 	if err != nil {
 		return nil, err
 	}
+	if err = writeSSHConfigFile(inst, sshLocalPort, sshOpts); err != nil {
+		return nil, err
+	}
 	sshConfig := &ssh.SSHConfig{
 		AdditionalArgs: sshutil.SSHArgsFromOpts(sshOpts),
 	}
@@ -150,6 +155,28 @@ func New(instName string, stdout io.Writer, sigintCh chan os.Signal, opts ...Opt
 	return a, nil
 }
 
+func writeSSHConfigFile(inst *store.Instance, sshLocalPort int, sshOpts []string) error {
+	if inst.Dir == "" {
+		return fmt.Errorf("directory is unknown for the instance %q", inst.Name)
+	}
+	var b bytes.Buffer
+	if _, err := fmt.Fprintf(&b, `# This SSH config file can be passed to 'ssh -F'.
+# This file is created by Lima, but not used by Lima itself currently.
+# Modifications to this file will be lost on restarting the Lima instance.
+`); err != nil {
+		return err
+	}
+	if err := sshutil.Format(&b, inst.Name, sshutil.FormatConfig,
+		append(sshOpts,
+			"Hostname=127.0.0.1",
+			fmt.Sprintf("Port=%d", sshLocalPort),
+		)); err != nil {
+		return err
+	}
+	fileName := filepath.Join(inst.Dir, filenames.SSHConfig)
+	return os.WriteFile(fileName, b.Bytes(), 0600)
+}
+
 func determineSSHLocalPort(y *limayaml.LimaYAML, instName string) (int, error) {
 	if *y.SSH.LocalPort > 0 {
 		return *y.SSH.LocalPort, nil
@@ -225,6 +252,11 @@ func (a *HostAgent) emitEvent(_ context.Context, ev events.Event) {
 	}
 }
 
+func generatePassword(length int) (string, error) {
+	// avoid any special symbols, to make it easier to copy/paste
+	return password.Generate(length, length/4, 0, false, false)
+}
+
 func (a *HostAgent) Run(ctx context.Context) error {
 	defer func() {
 		exitingEv := events.Event{
@@ -259,6 +291,50 @@ func (a *HostAgent) Run(ctx context.Context) error {
 		return err
 	}
 
+	if a.y.Video.Display != nil && *a.y.Video.Display == "vnc" {
+		vncdisplay, vncoptions, _ := strings.Cut(*a.y.Video.VNC.Display, ",")
+		vnchost, vncnum, err := net.SplitHostPort(vncdisplay)
+		if err != nil {
+			return err
+		}
+		n, err := strconv.Atoi(vncnum)
+		if err != nil {
+			return err
+		}
+		vncport := strconv.Itoa(5900 + n)
+		vncpwdfile := filepath.Join(a.instDir, filenames.VNCPasswordFile)
+		vncpasswd, err := generatePassword(8)
+		if err != nil {
+			return err
+		}
+		if err := a.driver.ChangeDisplayPassword(ctx, vncpasswd); err != nil {
+			return err
+		}
+		if err := os.WriteFile(vncpwdfile, []byte(vncpasswd), 0600); err != nil {
+			return err
+		}
+		if strings.Contains(vncoptions, "to=") {
+			vncport, err = a.driver.GetDisplayConnection(ctx)
+			if err != nil {
+				return err
+			}
+			p, err := strconv.Atoi(vncport)
+			if err != nil {
+				return err
+			}
+			vncnum = strconv.Itoa(p - 5900)
+			vncdisplay = net.JoinHostPort(vnchost, vncnum)
+		}
+		vncfile := filepath.Join(a.instDir, filenames.VNCDisplayFile)
+		if err := os.WriteFile(vncfile, []byte(vncdisplay), 0600); err != nil {
+			return err
+		}
+		vncurl := "vnc://" + net.JoinHostPort(vnchost, vncport)
+		logrus.Infof("VNC server running at %s <%s>", vncdisplay, vncurl)
+		logrus.Infof("VNC Display: `%s`", vncfile)
+		logrus.Infof("VNC Password: `%s`", vncpwdfile)
+	}
+
 	stBase := events.Status{
 		SSHLocalPort: a.sshLocalPort,
 	}
@@ -317,6 +393,19 @@ func (a *HostAgent) startHostAgentRoutines(ctx context.Context) error {
 	if err := a.waitForRequirements(ctx, "essential", a.essentialRequirements()); err != nil {
 		mErr = multierror.Append(mErr, err)
 	}
+	if *a.y.SSH.ForwardAgent {
+		faScript := `#!/bin/bash
+set -eux -o pipefail
+sudo mkdir -p -m 700 /run/host-services
+sudo ln -sf "${SSH_AUTH_SOCK}" /run/host-services/ssh-auth.sock
+sudo chown -R "${USER}" /run/host-services`
+		faDesc := "linking ssh auth socket to static location /run/host-services/ssh-auth.sock"
+		stdout, stderr, err := ssh.ExecuteScript("127.0.0.1", a.sshLocalPort, a.sshConfig, faScript, faDesc)
+		logrus.Debugf("stdout=%q, stderr=%q, err=%v", stdout, stderr, err)
+		if err != nil {
+			mErr = multierror.Append(mErr, fmt.Errorf("stdout=%q, stderr=%q: %w", stdout, stderr, err))
+		}
+	}
 	if *a.y.MountType == limayaml.REVSSHFS {
 		mounts, err := a.setupMounts(ctx)
 		if err != nil {
@@ -356,6 +445,12 @@ func (a *HostAgent) startHostAgentRoutines(ctx context.Context) error {
 	if err := a.waitForRequirements(ctx, "final", a.finalRequirements()); err != nil {
 		mErr = multierror.Append(mErr, err)
 	}
+	// Copy all config files _after_ the requirements are done
+	for _, rule := range a.y.CopyToHost {
+		if err := copyToHost(ctx, a.sshConfig, a.sshLocalPort, rule.HostFile, rule.GuestFile); err != nil {
+			mErr = multierror.Append(mErr, err)
+		}
+	}
 	return mErr
 }
 
@@ -525,3 +620,30 @@ func forwardSSH(ctx context.Context, sshConfig *ssh.SSHConfig, port int, local,
 	}
 	return nil
 }
+
+func copyToHost(ctx context.Context, sshConfig *ssh.SSHConfig, port int, local, remote string) error {
+	args := sshConfig.Args()
+	args = append(args,
+		"-p", strconv.Itoa(port),
+		"127.0.0.1",
+		"--",
+	)
+	args = append(args,
+		"sudo",
+		"cat",
+		remote,
+	)
+	logrus.Infof("Copying config from %s to %s", remote, local)
+	if err := os.MkdirAll(filepath.Dir(local), 0700); err != nil {
+		return fmt.Errorf("can't create directory for local file %q: %w", local, err)
+	}
+	cmd := exec.CommandContext(ctx, sshConfig.Binary(), args...)
+	out, err := cmd.Output()
+	if err != nil {
+		return fmt.Errorf("failed to run %v: %q: %w", cmd.Args, string(out), err)
+	}
+	if err := os.WriteFile(local, out, 0600); err != nil {
+		return fmt.Errorf("can't write to local file %q: %w", local, err)
+	}
+	return nil
+}
