@@ -30,7 +30,7 @@ const (
 )
 
 func defaultContainerdArchives() []File {
-	const nerdctlVersion = "1.1.0"
+	const nerdctlVersion = "1.2.1"
 	location := func(goarch string) string {
 		return "https://github.com/containerd/nerdctl/releases/download/v" + nerdctlVersion + "/nerdctl-full-" + nerdctlVersion + "-linux-" + goarch + ".tar.gz"
 	}
@@ -38,12 +38,12 @@ func defaultContainerdArchives() []File {
 		{
 			Location: location("amd64"),
 			Arch:     X8664,
-			Digest:   "sha256:5440c7b3af63df2ad2c98e185e06a27b4a21eea334b05408e84f8502251d9459",
+			Digest:   "sha256:e8a3e40d442c566ee494375a4c563121da69d7c7837f50f4a3a171742757b36c",
 		},
 		{
 			Location: location("arm64"),
 			Arch:     AARCH64,
-			Digest:   "sha256:3b613a1be5a24460c44bb93a3609b790ada94e06efd1a86467d45bec7da8b449",
+			Digest:   "sha256:1334bedbc9704994795bae88138807bd74e8bf2a23717491af5b8ae3aebebcda",
 		},
 		// No riscv64
 	}
@@ -186,6 +186,16 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		y.Video.Display = pointer.String("none")
 	}
 
+	if y.Video.VNC.Display == nil {
+		y.Video.VNC.Display = d.Video.VNC.Display
+	}
+	if o.Video.VNC.Display != nil {
+		y.Video.VNC.Display = o.Video.VNC.Display
+	}
+	if (y.Video.VNC.Display == nil || *y.Video.VNC.Display == "") && *y.VMType == QEMU {
+		y.Video.VNC.Display = pointer.String("127.0.0.1:0,to=9")
+	}
+
 	if y.Firmware.LegacyBIOS == nil {
 		y.Firmware.LegacyBIOS = d.Firmware.LegacyBIOS
 	}
@@ -315,6 +325,11 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		// After defaults processing the singular HostPort and GuestPort values should not be used again.
 	}
 
+	y.CopyToHost = append(append(o.CopyToHost, y.CopyToHost...), d.CopyToHost...)
+	for i := range y.CopyToHost {
+		FillCopyToHostDefaults(&y.CopyToHost[i], instDir)
+	}
+
 	if y.HostResolver.Enabled == nil {
 		y.HostResolver.Enabled = d.HostResolver.Enabled
 	}
@@ -527,6 +542,47 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 	y.CACertificates.Certs = caCerts
 }
 
+func executeGuestTemplate(format string) (bytes.Buffer, error) {
+	tmpl, err := template.New("").Parse(format)
+	if err == nil {
+		user, _ := osutil.LimaUser(false)
+		data := map[string]string{
+			"Home": fmt.Sprintf("/home/%s.linux", user.Username),
+			"UID":  user.Uid,
+			"User": user.Username,
+		}
+		var out bytes.Buffer
+		if err := tmpl.Execute(&out, data); err == nil {
+			return out, nil
+		}
+	}
+	return bytes.Buffer{}, err
+}
+
+func executeHostTemplate(format string, instDir string) (bytes.Buffer, error) {
+	tmpl, err := template.New("").Parse(format)
+	if err == nil {
+		user, _ := osutil.LimaUser(false)
+		home, _ := os.UserHomeDir()
+		limaHome, _ := dirnames.LimaDir()
+		data := map[string]string{
+			"Dir":  instDir,
+			"Home": home,
+			"Name": filepath.Base(instDir),
+			"UID":  user.Uid,
+			"User": user.Username,
+
+			"Instance": filepath.Base(instDir), // DEPRECATED, use `{{.Name}}`
+			"LimaHome": limaHome,               // DEPRECATED, (use `Dir` instead of `{{.LimaHome}}/{{.Instance}}`
+		}
+		var out bytes.Buffer
+		if err := tmpl.Execute(&out, data); err == nil {
+			return out, nil
+		}
+	}
+	return bytes.Buffer{}, err
+}
+
 func FillPortForwardDefaults(rule *PortForward, instDir string) {
 	if rule.Proto == "" {
 		rule.Proto = TCP
@@ -559,44 +615,17 @@ func FillPortForwardDefaults(rule *PortForward, instDir string) {
 		}
 	}
 	if rule.GuestSocket != "" {
-		tmpl, err := template.New("").Parse(rule.GuestSocket)
-		if err == nil {
-			user, _ := osutil.LimaUser(false)
-			data := map[string]string{
-				"Home": fmt.Sprintf("/home/%s.linux", user.Username),
-				"UID":  user.Uid,
-				"User": user.Username,
-			}
-			var out bytes.Buffer
-			if err := tmpl.Execute(&out, data); err == nil {
-				rule.GuestSocket = out.String()
-			} else {
-				logrus.WithError(err).Warnf("Couldn't process guestSocket %q as a template", rule.GuestSocket)
-			}
+		if out, err := executeGuestTemplate(rule.GuestSocket); err == nil {
+			rule.GuestSocket = out.String()
+		} else {
+			logrus.WithError(err).Warnf("Couldn't process guestSocket %q as a template", rule.GuestSocket)
 		}
 	}
 	if rule.HostSocket != "" {
-		tmpl, err := template.New("").Parse(rule.HostSocket)
-		if err == nil {
-			user, _ := osutil.LimaUser(false)
-			home, _ := os.UserHomeDir()
-			limaHome, _ := dirnames.LimaDir()
-			data := map[string]string{
-				"Dir":  instDir,
-				"Home": home,
-				"Name": filepath.Base(instDir),
-				"UID":  user.Uid,
-				"User": user.Username,
-
-				"Instance": filepath.Base(instDir), // DEPRECATED, use `{{.Name}}`
-				"LimaHome": limaHome,               // DEPRECATED, (use `Dir` instead of `{{.LimaHome}}/{{.Instance}}`
-			}
-			var out bytes.Buffer
-			if err := tmpl.Execute(&out, data); err == nil {
-				rule.HostSocket = out.String()
-			} else {
-				logrus.WithError(err).Warnf("Couldn't process hostSocket %q as a template", rule.HostSocket)
-			}
+		if out, err := executeHostTemplate(rule.HostSocket, instDir); err == nil {
+			rule.HostSocket = out.String()
+		} else {
+			logrus.WithError(err).Warnf("Couldn't process hostSocket %q as a template", rule.HostSocket)
 		}
 		if !filepath.IsAbs(rule.HostSocket) {
 			rule.HostSocket = filepath.Join(instDir, filenames.SocketDir, rule.HostSocket)
@@ -604,6 +633,23 @@ func FillPortForwardDefaults(rule *PortForward, instDir string) {
 	}
 }
 
+func FillCopyToHostDefaults(rule *CopyToHost, instDir string) {
+	if rule.GuestFile != "" {
+		if out, err := executeGuestTemplate(rule.GuestFile); err == nil {
+			rule.GuestFile = out.String()
+		} else {
+			logrus.WithError(err).Warnf("Couldn't process guest %q as a template", rule.GuestFile)
+		}
+	}
+	if rule.HostFile != "" {
+		if out, err := executeHostTemplate(rule.HostFile, instDir); err == nil {
+			rule.HostFile = out.String()
+		} else {
+			logrus.WithError(err).Warnf("Couldn't process host %q as a template", rule.HostFile)
+		}
+	}
+}
+
 func NewArch(arch string) Arch {
 	switch arch {
 	case "amd64":
