@@ -72,6 +72,9 @@ func TestFillDefault(t *testing.T) {
 		},
 		Video: Video{
 			Display: pointer.String("none"),
+			VNC: VNCOptions{
+				Display: pointer.String("127.0.0.1:0,to=9"),
+			},
 		},
 		HostResolver: HostResolver{
 			Enabled: pointer.Bool(true),
@@ -135,6 +138,12 @@ func TestFillDefault(t *testing.T) {
 				HostSocket:  "{{.Home}} | {{.Dir}} | {{.Name}} | {{.UID}} | {{.User}}",
 			},
 		},
+		CopyToHost: []CopyToHost{
+			{
+				GuestFile: "{{.Home}} | {{.UID}} | {{.User}}",
+				HostFile:  "{{.Home}} | {{.Dir}} | {{.Name}} | {{.UID}} | {{.User}}",
+			},
+		},
 		Env: map[string]string{
 			"ONE": "Eins",
 		},
@@ -183,6 +192,10 @@ func TestFillDefault(t *testing.T) {
 		defaultPortForward,
 		defaultPortForward,
 	}
+	expect.CopyToHost = []CopyToHost{
+		{},
+	}
+
 	// Setting GuestPort and HostPort for DeepEqual(), but they are not supposed to be used
 	// after FillDefault() has been called and the ...PortRange fields have been set.
 	expect.PortForwards[1].GuestPort = 80
@@ -197,6 +210,9 @@ func TestFillDefault(t *testing.T) {
 	expect.PortForwards[3].GuestSocket = fmt.Sprintf("%s | %s | %s", guestHome, user.Uid, user.Username)
 	expect.PortForwards[3].HostSocket = fmt.Sprintf("%s | %s | %s | %s | %s", hostHome, instDir, instName, user.Uid, user.Username)
 
+	expect.CopyToHost[0].GuestFile = fmt.Sprintf("%s | %s | %s", guestHome, user.Uid, user.Username)
+	expect.CopyToHost[0].HostFile = fmt.Sprintf("%s | %s | %s | %s | %s", hostHome, instDir, instName, user.Uid, user.Username)
+
 	expect.Env = y.Env
 
 	expect.CACertificates = CACertificates{
@@ -249,6 +265,9 @@ func TestFillDefault(t *testing.T) {
 		},
 		Video: Video{
 			Display: pointer.String("cocoa"),
+			VNC: VNCOptions{
+				Display: pointer.String("none"),
+			},
 		},
 		HostResolver: HostResolver{
 			Enabled: pointer.Bool(false),
@@ -298,6 +317,7 @@ func TestFillDefault(t *testing.T) {
 			HostPortRange:  [2]int{80, 80},
 			Proto:          TCP,
 		}},
+		CopyToHost: []CopyToHost{{}},
 		Env: map[string]string{
 			"ONE": "one",
 			"TWO": "two",
@@ -346,6 +366,7 @@ func TestFillDefault(t *testing.T) {
 	expect.Provision = append(y.Provision, d.Provision...)
 	expect.Probes = append(y.Probes, d.Probes...)
 	expect.PortForwards = append(y.PortForwards, d.PortForwards...)
+	expect.CopyToHost = append(y.CopyToHost, d.CopyToHost...)
 	expect.Containerd.Archives = append(y.Containerd.Archives, d.Containerd.Archives...)
 	expect.AdditionalDisks = append(y.AdditionalDisks, d.AdditionalDisks...)
 
@@ -403,6 +424,9 @@ func TestFillDefault(t *testing.T) {
 		},
 		Video: Video{
 			Display: pointer.String("cocoa"),
+			VNC: VNCOptions{
+				Display: pointer.String("none"),
+			},
 		},
 		HostResolver: HostResolver{
 			Enabled: pointer.Bool(false),
@@ -465,6 +489,7 @@ func TestFillDefault(t *testing.T) {
 			HostPortRange:  [2]int{8080, 8080},
 			Proto:          TCP,
 		}},
+		CopyToHost: []CopyToHost{{}},
 		Env: map[string]string{
 			"TWO":   "deux",
 			"THREE": "trois",
@@ -481,6 +506,7 @@ func TestFillDefault(t *testing.T) {
 	expect.Provision = append(append(o.Provision, y.Provision...), d.Provision...)
 	expect.Probes = append(append(o.Probes, y.Probes...), d.Probes...)
 	expect.PortForwards = append(append(o.PortForwards, y.PortForwards...), d.PortForwards...)
+	expect.CopyToHost = append(append(o.CopyToHost, y.CopyToHost...), d.CopyToHost...)
 	expect.Containerd.Archives = append(append(o.Containerd.Archives, y.Containerd.Archives...), d.Containerd.Archives...)
 	expect.AdditionalDisks = append(append(o.AdditionalDisks, y.AdditionalDisks...), d.AdditionalDisks...)
 
