@@ -249,6 +249,19 @@ func Validate(y LimaYAML, warn bool) error {
 		// Not validating that the various GuestPortRanges and HostPortRanges are not overlapping. Rules will be
 		// processed sequentially and the first matching rule for a guest port determines forwarding behavior.
 	}
+	for i, rule := range y.CopyToHost {
+		field := fmt.Sprintf("CopyToHost[%d]", i)
+		if rule.GuestFile != "" {
+			if !path.IsAbs(rule.GuestFile) {
+				return fmt.Errorf("field `%s.guest` must be an absolute path", field)
+			}
+		}
+		if rule.HostFile != "" {
+			if !filepath.IsAbs(rule.HostFile) {
+				return fmt.Errorf("field `%s.host` must be an absolute path, but is %q", field, rule.HostFile)
+			}
+		}
+	}
 
 	if y.HostResolver.Enabled != nil && *y.HostResolver.Enabled && len(y.DNS) > 0 {
 		return fmt.Errorf("field `dns` must be empty when field `HostResolver.Enabled` is true")
@@ -257,6 +270,9 @@ func Validate(y LimaYAML, warn bool) error {
 	if err := validateNetwork(y, warn); err != nil {
 		return err
 	}
+	if warn {
+		warnExperimental(y)
+	}
 	return nil
 }
 
@@ -401,3 +417,18 @@ func validatePort(field string, port int) error {
 	}
 	return nil
 }
+
+func warnExperimental(y LimaYAML) {
+	if *y.MountType == NINEP {
+		logrus.Warn("`mountType: 9p` is experimental")
+	}
+	if *y.VMType == VZ {
+		logrus.Warn("`vmType: vz` is experimental")
+	}
+	if *y.Arch == RISCV64 {
+		logrus.Warn("`arch: riscv64` is experimental")
+	}
+	if y.Video.Display != nil && strings.Contains(*y.Video.Display, "vnc") {
+		logrus.Warn("`video.display: vnc` is experimental")
+	}
+}
