@@ -11,6 +11,7 @@ import (
 	"os/exec"
 	"path/filepath"
 	"regexp"
+	"runtime"
 	"strings"
 	"sync"
 
@@ -20,6 +21,7 @@ import (
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/sirupsen/logrus"
+	"golang.org/x/sys/cpu"
 )
 
 type PubKey struct {
@@ -294,3 +296,24 @@ func detectValidPublicKey(content string) bool {
 	var sigFormat = string(decodedKey[4 : 4+sigLength])
 	return algo == sigFormat
 }
+
+func detectAESAcceleration() bool {
+	if !cpu.Initialized {
+		if runtime.GOOS == "darwin" && runtime.GOARCH == "arm64" {
+			// golang.org/x/sys/cpu supports darwin/amd64, linux/amd64, and linux/arm64,
+			// but apparently lacks support for darwin/arm64: https://github.com/golang/sys/blob/v0.5.0/cpu/cpu_arm64.go#L43-L60
+			//
+			// According to https://gist.github.com/voluntas/fd279c7b4e71f9950cfd4a5ab90b722b ,
+			// aes-128-gcm is faster than chacha20-poly1305 on Apple M1.
+			//
+			// So we return `true` here.
+			//
+			// This workaround will not be needed when https://go-review.googlesource.com/c/sys/+/332729 is merged.
+			logrus.Debug("Failed to detect CPU features. Assuming that AES acceleration is available on this Apple silicon.")
+			return true
+		}
+		logrus.Warn("Failed to detect CPU features. Assuming that AES acceleration is not available.")
+		return false
+	}
+	return cpu.ARM.HasAES || cpu.ARM64.HasAES || cpu.S390X.HasAES || cpu.X86.HasAES
+}
